<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  初期登録ユーザのIDの取得
 *
 *  @access public
 */
function db_get_user4first_user_id()
{
    $sql = 'SELECT user_id' .
            ' FROM pb_user' .
            ' ORDER BY r_datetime';
    return pocket_db_getOne($sql);
}

/**
 *  ユーザ情報の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_get_user($user_id)
{
    $sql = 'SELECT user_id, id, email, nickname, birth_year, birth_month, birth_day, sex, blood_type, self_intro, r_datetime' .
            ' FROM pb_user' .
            ' WHERE user_id = ?';
    $params = array(
        intval($user_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  ユーザID情報の取得
 *
 *  @access public
 *  @param  integer $id                 ID
 */
function db_get_user_id($id)
{
    $sql = 'SELECT user_id' .
            ' FROM pb_user' .
            ' WHERE id = ?';
    $params = array(
        $id
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  ユーザ情報の登録
 *
 *  @access public
 *  @param  string  $id                 ID
 *  @param  string  $nickname           ニックネーム
 *  @param  string  $birth_year         生まれた年
 *  @param  string  $birth_month        誕生日（月）
 *  @param  string  $birth_day          誕生日（日）
 */
function db_insert_userEasyProfile($id, $nickname, $birth_year, $birth_month, $birth_day)
{
    $data = array(
        'id' => $id,
        'nickname' => $nickname,
        'birth_year' => $birth_year,
        'birth_month' => $birth_month,
        'birth_day' => $birth_day,
        'r_datetime' => pocket_db_getNow(),
        'm_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pb_user', $data, 'pb_user_user_id_seq');
}

/**
 *  ユーザプロフィール情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $nickname           ニックネーム
 *  @param  string  $birth_year         生まれた年
 *  @param  string  $birth_month        誕生日（月）
 *  @param  string  $birth_day          誕生日（日）
 *  @param  string  $sex                性別
 *  @param  string  $blood_type         血液型
 *  @param  string  $self_intro         自己紹介
 */
function db_update_userProfile($user_id, $nickname, $birth_year, $birth_month, $birth_day, $sex, $blood_type, $self_intro)
{
    $data = array(
        'nickname' => $nickname,
        'birth_year' => $birth_year,
        'birth_month' => $birth_month,
        'birth_day' => $birth_day,
        'sex' => $sex,
        'blood_type' => $blood_type,
        'self_intro' => $self_intro,
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('pb_user', $data, $where);
}

/**
 *  メールアドレス情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $email              メールアドレス
 */
function db_update_userEmail($user_id, $email)
{
    $data = array(
        'email' => $email,
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('pb_user', $data, $where);
}

/**
 *  パスワード情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $password           パスワード
 */
function db_update_userPassword($user_id, $password)
{
    $data = array(
        'password' => $password,
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('pb_user', $data, $where);
}

/**
 *  ユーザ（メールアドレス）の存在チェック
 *
 *  @access public
 *  @param  string  $email              メールアドレス
 */
function db_is_exist_user4email($email)
{
    $sql = 'SELECT user_id' .
            ' FROM pb_user' .
            ' WHERE email = ?';
    $params = array(
        $email
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  ユーザ（メールアドレス）の存在チェック（自分以外）
 *
 *  @access public
 *  @param  string  $user_id            ユーザID
 *  @param  string  $email              メールアドレス
 */
function db_is_exist_user4another_person_email($user_id, $email)
{
    $sql = 'SELECT user_id' .
            ' FROM pr_user' .
            ' WHERE user_id <> ?' .
            ' AND email = ?';
    $params = array(
        $user_id,
        $email
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  メールアドレス認証
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $email              メールアドレス
 */
function db_auth_user4email($user_id, $email)
{
    $sql = 'SELECT user_id' .
            ' FROM pb_user' .
            ' WHERE user_id = ?' .
            ' AND email = ?';
    $params = array(
        intval($user_id),
        $email
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  パスワード認証
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $password           パスワード
 */
function db_auth_user4password($user_id, $password)
{
    $sql = 'SELECT user_id' .
            ' FROM pb_user' .
            ' WHERE user_id = ?' .
            ' AND password = ?';
    $params = array(
        intval($user_id),
        $password
    );
    return (bool)pocket_db_getOne($sql, $params);
}

?>
