<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  記事情報登録用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBlog.pc.do
 */
class postInsertAction extends Pocket_Blog_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $subject       = $request['subject'];
        $category_id   = $request['category_id'];
        $is_open       = $request['is_open'];
        $allow_comment = $request['allow_comment'];
        $trackback_url = $request['trackback_url'];
        $body          = $request['body'];

        // 記事の登録
        $post_id = db_insert_post($subject, $category_id, $is_open, $allow_comment, $trackback_url, $body);

        // トラックバックオブジェクトの生成
        $tb = new Pocket_Trackback();
        // トラックバック情報の送信
        $tb->send($trackback_url, BLOG_NAME, $subject, pocket_getSiteUrl() . '?m=pc&a=postComment.view&post_id=' . $post_id, $body);

        // リダイレクト
        pocket_redirect('postComment.view', array('post_id' => $post_id));
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $subject       = $request['subject'];
        $category_id   = $request['category_id'];
        $is_open       = $request['is_open'];
        $allow_comment = $request['allow_comment'];
        $trackback_url = $request['trackback_url'];
        $body          = $request['body'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'postEntry';

        // 検証
        $validator->validate('subject'      , 'タイトル'             , $subject      , 'string', true);
        $validator->validate('category_id'  , 'カテゴリ'             , $category_id  , 'number', true);
        $validator->validate('is_open'      , '公開状態'             , $is_open      , 'number', true);
        $validator->validate('allow_comment', 'コメント許可'         , $allow_comment, 'number', true);
        $validator->validate('trackback_url', 'トラックバック先のURL', $trackback_url, 'url');
        $validator->validate('body'         , '本文'                 , $body         , 'string', true);
    }

    /**
     *  認証アクションフラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isSecure()
    {
        return true;
    }
}

?>
